/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.core;

import java.util.Iterator;
import java.util.List;

/**
 * 
 * Iterable that will go over a list and will keep going even if the lists gets
 * modified while the iteration is in progress.
 * 
 * It will make a best effort to iterator over all elements, even ones that are
 * included after the iterator has started, but makes no guarantee that all
 * elements will be presented.
 * 
 * @author Thomas Abeel
 * 
 * @param <T>
 */
public class NoFailIterable<T> implements Iterable<T> {
	private List<T> list = null;

	public NoFailIterable(List<T> list) {
		this.list = list;
	}

	@Override
	public Iterator<T> iterator() {
		return new Iterator<T>() {
			private int idx = 0;

			@Override
			public boolean hasNext() {
				return idx <= list.size() - 1;
			}

			@Override
			public T next() {
				return list.get(idx++);
			}

			@Override
			public void remove() {
				throw new UnsupportedOperationException();

			}

		};
	}
}