/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.data.provider;

import java.util.logging.Logger;

import net.sf.genomeview.data.Model;
import net.sf.genomeview.data.Task;
import net.sf.jannot.Data;
import net.sf.jannot.Location;
import net.sf.jannot.pileup.DoublePile;
import net.sf.jannot.pileup.Pile;
/**
 * 
 * @author Thomas Abeel
 *
 */
class PileupTask extends Task {

	private Logger log = Logger.getLogger(PileupTask.class.toString());

	private int idx;
	private Data<Pile> pw;
	private PileupSummary summary;

	private Model model;

	public PileupTask(Data<Pile> pw, int idx, PileupSummary summary,Model model) {
		super(new Location(idx * PileupSummary.CHUNK, (idx + 1) * PileupSummary.CHUNK));
		this.model=model;
		this.pw = pw;
		this.summary = summary;
		this.idx = idx;

	}

	
	private boolean cancelled=false;
	@Override
	public void cancel(){
		super.cancel();
		summary.complyCancel(idx);
		this.cancelled=true;
	}
	
	public boolean isCancelled(){
		return cancelled;
	}
	
	@Override
	public void run() {
		try {
			if(model.isExitRequested())
				return;
			if(cancelled){
				summary.complyCancel(idx);
				return;
			}
			summary.setRunning(idx);
			Iterable<Pile> piles = pw.get(idx * PileupSummary.CHUNK, (idx + 1) * PileupSummary.CHUNK);
			for (Pile p : piles) {
				if (p.start() >= idx * PileupSummary.CHUNK && p.start() < (idx + 1) * PileupSummary.CHUNK) {
					int position = (p.start() - 1) / PileupSummary.SUMMARYSIZE;
					summary.add(position, p.getValue(0),p.getValue(1));

				}
			}
			// System.out.println("Pilerequest: " + idx + " completed " +
			// maxSummary);

			summary.conditionalQueue(pw, idx + 1);
			summary.setReady(idx);

		} catch (Exception e) {
			log.severe("Scheduler exception: " + pw + "\t" + idx + "\tpw.get(" + idx * PileupSummary.CHUNK + ", "
					+ (idx + 1) * PileupSummary.CHUNK + ")\n\t" + e);
		} catch (Error er) {
			log.severe("Scheduler error: " + pw + "\t" + idx + "\tpw.get(" + idx * PileupSummary.CHUNK + ", "
					+ (idx + 1) * PileupSummary.CHUNK + ")\n\t" + er);
		}
	}
}