/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.search;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Set;

import net.sf.genomeview.data.Model;
import net.sf.jannot.Feature;
import net.sf.jannot.FeatureAnnotation;
import net.sf.jannot.Type;

/**
 * 
 * @author Thomas Abeel
 * 
 */
class OverlapSearchResultModel extends AbstractSearchResultModel {

	private static final long serialVersionUID = 5850270831525342543L;

	private ArrayList<Feature> features = new ArrayList<Feature>();

	private Set<Feature> featuresSet = new HashSet<Feature>();

	OverlapSearchResultModel(Model model) {
		super(model);
	}

	void search(Type source, Type target) {
		for (Feature f : ((FeatureAnnotation) model.vlm.getSelectedEntry().get(source)).get()) {
			for (Feature g : ((FeatureAnnotation) model.vlm.getSelectedEntry().get(target)).get()) {
				if (f.overlaps(g)) {
					features.add(f);
					break;
				}

			}

		}
		fireTableDataChanged();

	}

	@Override
	public String getColumnName(int col) {
		return "Feature";

	}

	@Override
	public int getColumnCount() {
		return 1;
	}

	@Override
	public int getRowCount() {
		return features.size();
	}

	@Override
	public Object getValueAt(int row, int col) {
		return features.get(row);
	}

	Feature getFeature(int row) {
		return features.get(row);
	}
	@Override
	void clear() {
		features.clear();
		featuresSet.clear();
		fireTableDataChanged();
	}
}